def main():
    banner = """
    ────────────────────────────────────────────────
               Lyric Programming Language
             © 2025 MiraNova Studios

        Lyric is coming soon.
        Visit http://miranova.studio/lyric.html
    ────────────────────────────────────────────────
    """
    print(banner.strip())

